## [**Parser**](reference/parser.md)

## [**Project**](reference/project.md)

---

## Events

### [\_Event](reference/event.md#event)

### [\_ByteEvent](reference/event.md#byteevent)

### [\_WordEvent](reference/event.md#wordevent)

### [\_DWordEvent](reference/event.md#dwordevent)

### [\_TextEvent](reference/event.md#textevent)

### [\_DataEvent](reference/event.md#dataevent)

### [\_ColorEvent](reference/event.md#colorevent)

---

# FLP Object Model

## [\_FLObject](reference/flobject.md)

---

## [Arrangement](reference/arrangement.md#arrangement)

### [Playlist](reference/arrangement.md#playlist)

### [TimeMarker](reference/arrangement.md#timemarker)

### [Track](reference/arrangement.md#track)

---

## [Channel](reference/channel.md#channel)

### [ChannelArp](reference/channel.md#channelarp)

### [ChannelFX](reference/channel.md#channelfx)

### [ChannelDelay](reference/channel.md#channeldelay)

### [ChannelEnvelopeLFO](reference/channel.md#channelenvelopelfo)

### [ChannelLevels](reference/channel.md#channellevels)

### [ChannelLevelOffsets](reference/channel.md#channelleveloffsets)

### [ChannelPolyphony](reference/channel.md#channelpolyphony)

### [ChannelTracking](reference/channel.md#channeltracking)

## [Filter](reference/channel.md#filter)

---

## [Insert](reference/insert.md#insert)

### [InsertSlot](reference/insert.md#insertslot)

---

## [Misc](reference/misc.md)

---

## [Pattern](reference/pattern.md#pattern)

### [PatternController](reference/pattern.md#patterncontroller)

### [PatternNote](reference/pattern.md#patternnote)

---

## [Plugin](reference/plugin.md#plugin)

### [VSTPlugin](reference/plugin.md#vstplugin)

---

Implementation of `Plugin` for these native FX plugins:

### [Fruity Balance](reference/plugin.md#fruity-balance)

### [Fruity Fast Dist](reference/plugin.md#fruity-fast-dist)

### [Fruity Notebook 2](reference/plugin.md#fruity-notebook-2)

### [Fruity Send](reference/plugin.md#fruity-send)

### [Fruity Soft Clipper](reference/plugin.md#fruity-soft-clipper)

### [Fruity Stereo Enhancer](reference/plugin.md#fruity-stereo-enhancer)

### [Soundgoodizer](reference/plugin.md#soundgoodizer)

---

Implementation of `Plugin` for these native generator plugins:

### [BooBass](reference/plugin.md#boobass)

---

## [Constants](reference/constants.md)

## [Exceptions](reference/exceptions.md)

## [Properties](reference/properties.md)

## [Utils](reference/utils.md)

## [Validators](reference/validators.md)
